package com.sooka.system.api;

import com.sooka.common.core.constant.SecurityConstants;
import com.sooka.common.core.constant.ServiceNameConstants;
import com.sooka.common.core.domain.R;
import com.sooka.system.api.domain.SysDept;
import com.sooka.system.api.domain.SysUser;
import com.sooka.system.api.factory.RemoteUserFallbackFactory;
import com.sooka.system.api.model.LoginUser;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 用户服务
 *
 * @author sooka
 */
@FeignClient(contextId = "remoteUserService" , value = ServiceNameConstants.SYSTEM_SERVICE, fallbackFactory = RemoteUserFallbackFactory.class)
public interface RemoteUserService {
    /**
     * 通过用户名查询用户信息
     *
     * @param username 用户名
     * @param source   请求来源
     * @return 结果
     */
    @GetMapping("/user/info/{username}")
    public R<LoginUser> getUserInfo(@PathVariable("username") String username, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 注册用户信息
     *
     * @param sysUser 用户信息
     * @param source  请求来源
     * @return 结果
     */
    @PostMapping("/user/register")
    public R<Boolean> registerUserInfo(@RequestBody SysUser sysUser, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 获取用户
     *
     * @param userId
     * @return
     */
    @GetMapping("/user/selectById/{userId}")
    R<SysUser> selectById(@PathVariable("userId") Long userId);

    /**
     * 根据DEPT_ID查询下级的部门列表
     *
     * @param deptId
     * @return
     */
    @GetMapping("/dept/selectChildrenCountyOrVillagesDeptListByDeptId")
    R<List<SysDept>> selectChildrenCountyOrVillagesDeptListByDeptId(@RequestParam(value = "deptId") Long deptId);
}
